<?php

/**
 *
 * CashBill Payment PHP SDK
 *
 * @author Lukasz Firek <lukasz.firek@cashbill.pl>
 * @version 1.0.0
 * @license MIT
 * @copyright CashBill S.A. 2015
 *
 * http://cashbill.pl
 *
 */
namespace CashBill\Payments\Model\Library\Model;

use CashBill\Payments\Model\Library\Interfaces\Data;
use CashBill\Payments\Model\Library\Services\CashBillTransactionException;

class Amount implements Data{
	
	/**
	 *
	 * @var array $paymentChannels
	 * @var string $lang
	 */
	private $value, $currencyCode;
	
	/**
	 *
	 * @param float $value        	
	 * @param string $currencyCode        	
	 */
	function __construct($value, $currencyCode) {
		
		if (! is_numeric ( $value )) {
			throw new CashBillTransactionException ( "Amount value not numeric" );
		}
		
		if (strlen ( $currencyCode ) != 3) {
			throw new CashBillTransactionException ( "Currency code not valid" );
		}
		
		$this->value = $value;
		$this->currencyCode = $currencyCode;
	}
	public static function fromArray($array) {
		return new Amount($array['value'], $array['currencyCode']);
	}
	
	/**
	 *
	 * @see CashBillData::toArray()
	 */
	public function toArray() {
		$array = array ();
		foreach ($this as $key => $value ) {
			$array ["amount.".$key ] = $value;
		}
		return $array;
	}

}
